"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var currency_mask_config_1 = require("./currency-mask.config");
var input_handler_1 = require("./input.handler");
exports.CURRENCYMASKDIRECTIVE_VALUE_ACCESSOR = {
    provide: forms_1.NG_VALUE_ACCESSOR,
    useExisting: core_1.forwardRef(function () { return CurrencyMaskDirective; }),
    multi: true
};
var CurrencyMaskDirective = /** @class */ (function () {
    function CurrencyMaskDirective(currencyMaskConfig, elementRef, keyValueDiffers, injector) {
        this.currencyMaskConfig = currencyMaskConfig;
        this.elementRef = elementRef;
        this.keyValueDiffers = keyValueDiffers;
        this.injector = injector;
        this.options = {};
        this.ngModelMoneyChange = new core_1.EventEmitter();
        this.optionsTemplate = {
            align: "right",
            allowNegative: true,
            decimal: ".",
            precision: 2,
            prefix: "$ ",
            suffix: "",
            thousands: ",",
        };
        if (currencyMaskConfig) {
            this.optionsTemplate = currencyMaskConfig;
        }
        this.keyValueDiffer = keyValueDiffers.find({}).create();
    }
    CurrencyMaskDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.isIonic = this.elementRef.nativeElement.children != undefined ? true : false;
        if (this.isIonic) {
            setTimeout(function () {
                _this.elementRef.nativeElement.children[0].style.textAlign = _this.options.align ? _this.options.align : _this.optionsTemplate.align;
            }, 0);
        }
        else {
            this.elementRef.nativeElement.style.textAlign = this.options.align ? this.options.align : this.optionsTemplate.align;
        }
    };
    CurrencyMaskDirective.prototype.ngDoCheck = function () {
        var _this = this;
        if (this.keyValueDiffer.diff(this.options)) {
            if (this.isIonic) {
                setTimeout(function () {
                    _this.elementRef.nativeElement.children[0].style.textAlign = _this.options.align ? _this.options.align : _this.optionsTemplate.align;
                    _this.inputHandler.updateOptions(Object.assign({}, _this.optionsTemplate, _this.options));
                }, 0);
            }
            else {
                this.elementRef.nativeElement.style.textAlign = this.options.align ? this.options.align : this.optionsTemplate.align;
                this.inputHandler.updateOptions(Object.assign({}, this.optionsTemplate, this.options));
            }
        }
    };
    CurrencyMaskDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.isIonic = this.elementRef.nativeElement.children != undefined ? true : false;
        this.ngModel = this.injector.get(forms_1.NgModel);
        if (this.isIonic) {
            setTimeout(function () {
                _this.inputHandler = new input_handler_1.InputHandler(_this.elementRef.nativeElement.children[0], Object.assign({}, _this.optionsTemplate, _this.options));
                if (_this.ngModel)
                    _this.inputHandler.setNgModel(_this.ngModel);
            }, 0);
        }
        else {
            this.inputHandler = new input_handler_1.InputHandler(this.elementRef.nativeElement, Object.assign({}, this.optionsTemplate, this.options));
            if (this.ngModel)
                this.inputHandler.setNgModel(this.ngModel);
        }
    };
    CurrencyMaskDirective.prototype.handleBlur = function (event) {
        if (this.isIonic) {
            this.ngModel.update.emit(this.inputHandler.getMaskedValue(this.ngModelMoney));
        }
        else {
            this.inputHandler.getOnModelTouched().apply(event);
        }
    };
    CurrencyMaskDirective.prototype.handleClick = function (event) {
        this.inputHandler.handleClick(event, this.isChromeAndroid());
    };
    CurrencyMaskDirective.prototype.handleCut = function (event) {
        if (!this.isChromeAndroid()) {
            if (this.isIonic)
                this.inputHandler.handleCut(event, this.ngModelMoneyChange);
            else
                this.inputHandler.handleCut(event);
        }
    };
    CurrencyMaskDirective.prototype.handleInput = function (event) {
        if (this.isChromeAndroid()) {
            if (this.isIonic)
                this.inputHandler.handleInput(event, this.ngModelMoneyChange);
            else
                this.inputHandler.handleInput(event);
        }
    };
    CurrencyMaskDirective.prototype.handleKeydown = function (event) {
        if (!this.isChromeAndroid()) {
            if (this.isIonic)
                this.inputHandler.handleKeydown(event, this.ngModelMoneyChange);
            else
                this.inputHandler.handleKeydown(event);
        }
    };
    CurrencyMaskDirective.prototype.handleKeypress = function (event) {
        if (!this.isChromeAndroid()) {
            if (this.isIonic)
                this.inputHandler.handleKeypress(event, this.ngModelMoneyChange);
            else
                this.inputHandler.handleKeypress(event);
        }
    };
    CurrencyMaskDirective.prototype.handleKeyup = function (event) {
        if (!this.isChromeAndroid()) {
            this.inputHandler.handleKeyup(event);
        }
    };
    CurrencyMaskDirective.prototype.handlePaste = function (event) {
        if (!this.isChromeAndroid()) {
            if (this.isIonic)
                this.inputHandler.handlePaste(event, this.ngModelMoneyChange);
            else
                this.inputHandler.handlePaste(event);
        }
    };
    CurrencyMaskDirective.prototype.isChromeAndroid = function () {
        return /chrome/i.test(navigator.userAgent) && /android/i.test(navigator.userAgent);
    };
    CurrencyMaskDirective.prototype.registerOnChange = function (callbackFunction) {
        this.inputHandler.setOnModelChange(callbackFunction);
    };
    CurrencyMaskDirective.prototype.registerOnTouched = function (callbackFunction) {
        this.inputHandler.setOnModelTouched(callbackFunction);
    };
    CurrencyMaskDirective.prototype.setDisabledState = function (value) {
        this.elementRef.nativeElement.children[0].disabled = value;
    };
    CurrencyMaskDirective.prototype.validate = function (abstractControl) {
        var result = {};
        if (abstractControl.value > this.max) {
            result.max = true;
        }
        if (abstractControl.value < this.min) {
            result.min = true;
        }
        return result != {} ? result : null;
    };
    CurrencyMaskDirective.prototype.writeValue = function (value) {
        this.inputHandler.setValue(value);
    };
    CurrencyMaskDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[currencyMask]",
                    providers: [
                        exports.CURRENCYMASKDIRECTIVE_VALUE_ACCESSOR,
                        { provide: forms_1.NG_VALIDATORS, useExisting: CurrencyMaskDirective, multi: true },
                    ]
                },] },
    ];
    /** @nocollapse */
    CurrencyMaskDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core_1.Optional }, { type: core_1.Inject, args: [currency_mask_config_1.CURRENCY_MASK_CONFIG,] },] },
        { type: core_1.ElementRef, },
        { type: core_1.KeyValueDiffers, },
        { type: core_1.Injector, },
    ]; };
    CurrencyMaskDirective.propDecorators = {
        "max": [{ type: core_1.Input },],
        "min": [{ type: core_1.Input },],
        "options": [{ type: core_1.Input },],
        "ngModelMoney": [{ type: core_1.Input },],
        "ngModelMoneyChange": [{ type: core_1.Output },],
        "handleBlur": [{ type: core_1.HostListener, args: ["blur", ["$event"],] },],
        "handleClick": [{ type: core_1.HostListener, args: ["click", ["$event"],] },],
        "handleCut": [{ type: core_1.HostListener, args: ["cut", ["$event"],] },],
        "handleInput": [{ type: core_1.HostListener, args: ["input", ["$event"],] },],
        "handleKeydown": [{ type: core_1.HostListener, args: ["keydown", ["$event"],] },],
        "handleKeypress": [{ type: core_1.HostListener, args: ["keypress", ["$event"],] },],
        "handleKeyup": [{ type: core_1.HostListener, args: ["keyup", ["$event"],] },],
        "handlePaste": [{ type: core_1.HostListener, args: ["paste", ["$event"],] },],
    };
    return CurrencyMaskDirective;
}());
exports.CurrencyMaskDirective = CurrencyMaskDirective;
//# sourceMappingURL=currency-mask.directive.js.map